@@ -35,11 +35,11 @@ extern "C" {
  *
  * Library version string
  */
-#define LIBFDISK_VERSION   "2.33.0"
+#define LIBFDISK_VERSION   "2.37.2"
 
 #define LIBFDISK_MAJOR_VERSION   2
-#define LIBFDISK_MINOR_VERSION   33
-#define LIBFDISK_PATCH_VERSION   0
+#define LIBFDISK_MINOR_VERSION   37
+#define LIBFDISK_PATCH_VERSION   2
 
 /**
  * fdisk_context:
@@ -144,7 +144,7 @@ struct fdisk_labelitem;
  * @FDISK_ASKTYPE_OFFSET:  ask for offset
  * @FDISK_ASKTYPE_WARN:  print warning message and errno
  * @FDISK_ASKTYPE_WARNX: print warning message
- * @FDISK_ASKTYPE_INFO: print infor message
+ * @FDISK_ASKTYPE_INFO: print info message
  * @FDISK_ASKTYPE_YESNO: ask Yes/No question
  * @FDISK_ASKTYPE_STRING: ask for string
  * @FDISK_ASKTYPE_MENU: ask for menu item
@@ -195,6 +195,8 @@ int fdisk_is_labeltype(struct fdisk_context *cxt, enum fdisk_labeltype id);
 
 int fdisk_assign_device(struct fdisk_context *cxt,
 			const char *fname, int readonly);
+int fdisk_assign_device_by_fd(struct fdisk_context *cxt, int fd,
+                        const char *fname, int readonly);
 int fdisk_deassign_device(struct fdisk_context *cxt, int nosync);
 int fdisk_reassign_device(struct fdisk_context *cxt);
 
@@ -262,7 +264,13 @@ int fdisk_parttype_set_typestr(struct fdisk_parttype *t, const char *str);
 int fdisk_parttype_set_code(struct fdisk_parttype *t, int code);
 size_t fdisk_label_get_nparttypes(const struct fdisk_label *lb);
 struct fdisk_parttype *fdisk_label_get_parttype(const struct fdisk_label *lb, size_t n);
+int fdisk_label_get_parttype_shortcut(
+	                        const struct fdisk_label *lb, size_t n,
+		                const char **typestr,
+			        const char **shortcut,
+				const char **alias);
 int fdisk_label_has_code_parttypes(const struct fdisk_label *lb);
+int fdisk_label_has_parttypes_shortcuts(const struct fdisk_label *lb);
 struct fdisk_parttype *fdisk_label_get_parttype_from_code(
 				const struct fdisk_label *lb,
 				unsigned int code);
@@ -275,6 +283,40 @@ struct fdisk_parttype *fdisk_copy_parttype(const struct fdisk_parttype *type);
 struct fdisk_parttype *fdisk_label_parse_parttype(
 				const struct fdisk_label *lb,
 				const char *str);
+struct fdisk_parttype *fdisk_label_advparse_parttype(
+				const struct fdisk_label *lb,
+				const char *str,
+				int flags);
+
+/**
+ * fdisk_parttype_parser_flags:
+ * @FDISK_PARTTYPE_PARSE_DATA: parse hex or UUID from string
+ * @FDISK_PARTTYPE_PARSE_DATALAST: try hex or UUID as the last possibility (don't use!)
+ * @FDISK_PARTTYPE_PARSE_SHORTCUT: try input as type shortcut (e.g 'L' for linux partition)
+ * @FDISK_PARTTYPE_PARSE_ALIAS: try input as type alias (e.g. 'linux' for linux partition)
+ * @FDISK_PARTTYPE_PARSE_DEPRECATED: accept also deprecated aliases and shortcuts
+ * @FDISK_PARTTYPE_PARSE_DEFAULT: recommended flags for new code
+ * @FDISK_PARTTYPE_PARSE_NOUNKNOWN: ignore unknown types
+ * @FDISK_PARTTYPE_PARSE_SEQNUM: use input as sequntial number of type (e.g. list-types fdisk dialog)
+ * @FDISK_PARTTYPE_PARSE_NAME: parse type human readable name
+ */
+enum fdisk_parttype_parser_flags {
+	FDISK_PARTTYPE_PARSE_DATA       = (1 << 1),
+	FDISK_PARTTYPE_PARSE_DATALAST   = (1 << 2),
+	FDISK_PARTTYPE_PARSE_SHORTCUT   = (1 << 3),
+	FDISK_PARTTYPE_PARSE_ALIAS      = (1 << 4),
+	FDISK_PARTTYPE_PARSE_DEPRECATED = (1 << 5),
+	FDISK_PARTTYPE_PARSE_NOUNKNOWN  = (1 << 6),
+	FDISK_PARTTYPE_PARSE_SEQNUM     = (1 << 7),
+	FDISK_PARTTYPE_PARSE_NAME	= (1 << 8),
+
+	FDISK_PARTTYPE_PARSE_DEFAULT = (FDISK_PARTTYPE_PARSE_DATA | \
+				        FDISK_PARTTYPE_PARSE_SHORTCUT | \
+				        FDISK_PARTTYPE_PARSE_ALIAS | \
+					FDISK_PARTTYPE_PARSE_NAME | \
+					FDISK_PARTTYPE_PARSE_SEQNUM )
+};
+
 const char *fdisk_parttype_get_string(const struct fdisk_parttype *t);
 unsigned int fdisk_parttype_get_code(const struct fdisk_parttype *t);
 const char *fdisk_parttype_get_name(const struct fdisk_parttype *t);
@@ -397,6 +439,7 @@ extern int fdisk_get_disklabel_item(struct fdisk_context *cxt, int id, struct fd
 
 extern int fdisk_get_disklabel_id(struct fdisk_context *cxt, char **id);
 extern int fdisk_set_disklabel_id(struct fdisk_context *cxt);
+extern int fdisk_set_disklabel_id_from_string(struct fdisk_context *cxt, const char *str);
 
 extern int fdisk_get_partition(struct fdisk_context *cxt, size_t partno, struct fdisk_partition **pa);
 extern int fdisk_set_partition(struct fdisk_context *cxt, size_t partno, struct fdisk_partition *pa);
@@ -619,7 +662,7 @@ extern int fdisk_bsd_link_partition(struct fdisk_context *cxt);
  * @BSD_LABELITEM_TYPE: type
  * @BSD_LABELITEM_DISK: disk
  * @BSD_LABELITEM_PACKNAME: packname
- * @BSD_LABELITEM_FLAGS: flags (removeable, ecc, badsect)
+ * @BSD_LABELITEM_FLAGS: flags (removable, ecc, badsect)
  * @BSD_LABELITEM_SECSIZE: Bytes/Sector
  * @BSD_LABELITEM_NTRACKS: Tracks/Cylinder
  * @BSD_LABELITEM_SECPERCYL: Sectors/Cylinder
@@ -721,17 +764,20 @@ enum fdisk_labelitem_sgi {
 #define GPT_FLAG_GUIDSPECIFIC	4
 
 extern int fdisk_gpt_is_hybrid(struct fdisk_context *cxt);
-extern int fdisk_gpt_set_npartitions(struct fdisk_context *cxt, uint32_t entries);
+extern int fdisk_gpt_set_npartitions(struct fdisk_context *cxt, uint32_t nents);
 extern int fdisk_gpt_get_partition_attrs(struct fdisk_context *cxt, size_t partnum, uint64_t *attrs);
 extern int fdisk_gpt_set_partition_attrs(struct fdisk_context *cxt, size_t partnum, uint64_t attrs);
 
+extern void fdisk_gpt_disable_relocation(struct fdisk_label *lb, int disable);
+extern void fdisk_gpt_enable_minimize(struct fdisk_label *lb, int enable);
+
 /**
  * fdisk_labelitem_gpt:
  * @GPT_LABELITEM_ID: GPT disklabel UUID (!= partition UUID)
  * @GPT_LABELITEM_FIRSTLBA: First Usable LBA
  * @GPT_LABELITEM_LASTLBA: Usable LBA
  * @GPT_LABELITEM_ALTLBA: Alternative LBA (backup header LBA)
- * @GPT_LABELITEM_ENTRIESLBA: Partitions entires array LBA
+ * @GPT_LABELITEM_ENTRIESLBA: Partitions entries array LBA
  * @GPT_LABELITEM_ENTRIESALLOC: Number of allocated entries in entries array
  *
  * GPT specific label items.
@@ -757,6 +803,7 @@ void fdisk_unref_script(struct fdisk_script *dp);
 const char *fdisk_script_get_header(struct fdisk_script *dp, const char *name);
 int fdisk_script_set_header(struct fdisk_script *dp, const char *name, const char *data);
 struct fdisk_table *fdisk_script_get_table(struct fdisk_script *dp);
+int fdisk_script_set_table(struct fdisk_script *dp, struct fdisk_table *tb);
 int fdisk_script_get_nlines(struct fdisk_script *dp);
 int fdisk_script_has_force_label(struct fdisk_script *dp);
 
@@ -828,9 +875,12 @@ size_t fdisk_ask_menu_get_nitems(struct fdisk_ask *ask);
 int fdisk_ask_print_get_errno(struct fdisk_ask *ask);
 const char *fdisk_ask_print_get_mesg(struct fdisk_ask *ask);
 
-int fdisk_info(struct fdisk_context *cxt, const char *fmt, ...);
-int fdisk_warn(struct fdisk_context *cxt, const char *fmt, ...);
-int fdisk_warnx(struct fdisk_context *cxt, const char *fmt, ...);
+int fdisk_info(struct fdisk_context *cxt, const char *fmt, ...)
+			__attribute__ ((__format__ (__printf__, 2, 3)));
+int fdisk_warn(struct fdisk_context *cxt, const char *fmt, ...)
+			__attribute__ ((__format__ (__printf__, 2, 3)));
+int fdisk_warnx(struct fdisk_context *cxt, const char *fmt, ...)
+			__attribute__ ((__format__ (__printf__, 2, 3)));
 
 /* utils.h */
 extern char *fdisk_partname(const char *dev, size_t partno);
